summaryrefslogtreecommitdiffstats
path: root/cpukit/score/include/rtems/score/scheduler.h
diff options
context:
space:
mode:
Diffstat (limited to 'cpukit/score/include/rtems/score/scheduler.h')
-rw-r--r--cpukit/score/include/rtems/score/scheduler.h21
1 files changed, 17 insertions, 4 deletions
diff --git a/cpukit/score/include/rtems/score/scheduler.h b/cpukit/score/include/rtems/score/scheduler.h
index 669f82c48c..a6066c8e4a 100644
--- a/cpukit/score/include/rtems/score/scheduler.h
+++ b/cpukit/score/include/rtems/score/scheduler.h
@@ -334,19 +334,32 @@ extern const Scheduler_Control _Scheduler_Table[];
#endif
/**
- * @brief Returns the thread priority.
+ * @brief Returns the scheduler internal thread priority mapped by
+ * SCHEDULER_PRIORITY_MAP().
*
* @param[in] scheduler Unused.
- * @param[in] priority The thread priority.
+ * @param[in] priority The user visible thread priority.
*
* @return priority The thread priority.
*/
Priority_Control _Scheduler_default_Map_priority(
const Scheduler_Control *scheduler,
Priority_Control priority
);
-#define _Scheduler_default_Unmap_priority _Scheduler_default_Map_priority
+/**
+ * @brief Returns the user visible thread priority unmapped by
+ * SCHEDULER_PRIORITY_UNMAP().
+ *
+ * @param[in] scheduler Unused.
+ * @param[in] priority The scheduler internal thread priority.
+ *
+ * @return priority The user visible thread priority.
+ */
+Priority_Control _Scheduler_default_Unmap_priority(
+ const Scheduler_Control *scheduler,
+ Priority_Control priority
+);
#if defined(RTEMS_SMP)
/**
@@ -334,19 +334,32 @@ extern const Scheduler_Control _Scheduler_Table[];
*
- * @return priority The thread priority.
+ * @return priority The scheduler internal thread priority.
*/
Priority_Control _Scheduler_default_Map_priority(